Next typedef
Next =
Future<ApiResponse> Function(ApiRequest request)
Function type for the next step in the middleware pipeline.
Implementation
typedef Next = Future<ApiResponse> Function(ApiRequest request);
Function type for the next step in the middleware pipeline.
typedef Next = Future<ApiResponse> Function(ApiRequest request);